.. include:: ../README.rst

.. note::

   This project is under active development.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Home <self>
   usage
   modules

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
